@@ -1,10 +1,11 @@
 package Test::CompanionClasses;
+# ABSTRACT: Basic invocation of the test companion class engine
 use 5.006;
 use warnings;
 use strict;
 use Test::CompanionClasses::Engine;
 use Getopt::Long;
-use base 'Exporter';
+use Exporter qw(import);
 our $VERSION = '0.06';
 our @EXPORT  = ('run_tests');
 
@@ -20,11 +21,18 @@ sub run_tests {
     );
 }
 1;
+
+
 __END__
+=pod
 
 =head1 NAME
 
-Test::CompanionClasses - Basic invocation of Test::CompanionClasses::Engine
+Test::CompanionClasses - Basic invocation of the test companion class engine
+
+=head1 VERSION
+
+version 1.100870
 
 =head1 SYNOPSIS
 
@@ -43,6 +51,13 @@ can use for your distribution test files (in C<t/>).
 
 The intention is that you use it as shown in the L</SYNOPSIS>.
 
+=head1 METHODS
+
+=head2 run_tests
+
+Parses the command-line options, then calls the C<run_tests()> method of
+L<Test::CompanionClasses::Engine>.
+
 =head1 COMMAND-LINE USAGE
 
 The following command-line arguments are supported:
@@ -61,48 +76,39 @@ Again, see L<Test::CompanionClasses::Engine> for details.
 
 The C<inherited> mechanism is not supported (yet).
 
-=head1 METHODS
+=head1 INSTALLATION
 
-=over 4
-
-=item C<run_tests>
-
-Parses the command-line options, then calls the C<run_tests()> method of
-L<Test::CompanionClasses::Engine>.
-
-=back
+See perlmodinstall for information and options on installing Perl modules.
 
 =head1 BUGS AND LIMITATIONS
 
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org>.
-
-=head1 INSTALLATION
-
-See perlmodinstall for information and options on installing Perl modules.
+L<http://rt.cpan.org/Public/Dist/Display.html?Name=Test-CompanionClasses>.
 
 =head1 AVAILABILITY
 
 The latest version of this module is available from the Comprehensive Perl
-Archive Network (CPAN). Visit <http://www.perl.com/CPAN/> to find a CPAN
-site near you. Or see L<http://search.cpan.org/dist/Test-CompanionClasses/>.
+Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
+site near you, or see
+L<http://search.cpan.org/dist/Test-CompanionClasses/>.
 
 The development version lives at
-L<http://github.com/hanekomu/test-companionclasses>. Instead of sending
-patches, please fork this project using the standard git and github
-infrastructure.
+L<http://github.com/hanekomu/Test-CompanionClasses/>.
+Instead of sending patches, please fork this project using the standard git
+and github infrastructure.
 
 =head1 AUTHOR
 
-Marcel GrE<uuml>nauer, C<< <marcel@cpan.org> >>
+  Marcel Gruenauer <marcel@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2007-2009 by Marcel GrE<uuml>nauer.
+This software is copyright (c) 2007 by Marcel Gruenauer.
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
