@@ -1,18 +1,19 @@
-package Test::CompanionClasses::Base;
+use 5.008;
 use strict;
 use warnings;
+
+package Test::CompanionClasses::Base;
+our $VERSION = '1.100870';
+# ABSTRACT: Base class for test companion classes
 use Test::More;
 use UNIVERSAL::require;
-our $VERSION = '0.06';
-use base qw(
+use parent qw(
   Class::Accessor::Complex
   Data::Inherited
 );
-#<<<
 __PACKAGE__
     ->mk_new
     ->mk_scalar_accessors(qw(package));
-#>>>
 use constant PLAN => 0;    # default
 
 sub make_real_object {
@@ -21,8 +22,7 @@ sub make_real_object {
     die $@ if $@;
     $self->package->new(@args);
 }
-
-sub run {}
+sub run { }
 
 # this can be called as a class method as well
 sub planned_test_count {
@@ -32,14 +32,20 @@ sub planned_test_count {
     $plan;
 }
 1;
-__END__
 
-=for test_synopsis
-my ($foo, $bar);
+
+__END__
+=pod
+
+=for test_synopsis my ($foo, $bar);
 
 =head1 NAME
 
-Test::CompanionClasses::Base - base class for test companion classes
+Test::CompanionClasses::Base - Base class for test companion classes
+
+=head1 VERSION
+
+version 1.100870
 
 =head1 SYNOPSIS
 
@@ -70,40 +76,7 @@ then C<package()> will return C<My::Foo>.
 
 =head1 METHODS
 
-=over 4
-
-=item C<new>
-
-    my $obj = Test::CompanionClasses::Base->new;
-    my $obj = Test::CompanionClasses::Base->new(%args);
-
-Creates and returns a new object. The constructor will accept as arguments a
-list of pairs, from component name to initial value. For each pair, the named
-component is initialized by calling the method of the same name with the given
-value. If called with a single hash reference, it is dereferenced and its
-key/value pairs are set as described before.
-
-=item C<clear_package>
-
-    $obj->clear_package;
-
-Clears the value.
-
-=item C<package>
-
-    my $value = $obj->package;
-    $obj->package($value);
-
-A basic getter/setter method. If called without an argument, it returns the
-value. If called with a single argument, it sets the value.
-
-=item C<package_clear>
-
-    $obj->package_clear;
-
-Clears the value.
-
-=item C<PLAN>
+=head2 PLAN
 
 A constant that says how many tests this particular class defines. Real test
 companion classes (i.e., subclasses of this class) will want to redefine it
@@ -114,12 +87,12 @@ like this:
 Note that you should only specify how many tests the current class runs; test
 counts of superclasses are automatically taken care of.
 
-=item C<planned_test_count>
+=head2 planned_test_count
 
 Uses C<PLAN()>, calculated over the test companion class' whole class
 hierarchy, to determine how many tests will be run in total.
 
-=item C<make_real_object>
+=head2 make_real_object
 
 Loads the actual class being tested (see C<package()>) and returns an object
 of this class (constructed by calling C<new()> on it).
@@ -127,7 +100,7 @@ of this class (constructed by calling C<new()> on it).
 In your test companion class you will want to test certain assumptions about
 your real class, so this method will be useful.
 
-=item C<run>
+=head2 run
 
 Test companion classes should override this method and run their tests. Be
 sure to call C<SUPER::run(@_)> so that all tests over the class hierarchy are
@@ -139,39 +112,39 @@ several companion classes - and you probably will or you won't have been using
 C<Test::CompanionClasses> - this serves as a visual distinction of where on
 companion class' tests end the next ones' begin.
 
-=back
+=head1 INSTALLATION
+
+See perlmodinstall for information and options on installing Perl modules.
 
 =head1 BUGS AND LIMITATIONS
 
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org>.
-
-=head1 INSTALLATION
-
-See perlmodinstall for information and options on installing Perl modules.
+L<http://rt.cpan.org/Public/Dist/Display.html?Name=Test-CompanionClasses>.
 
 =head1 AVAILABILITY
 
 The latest version of this module is available from the Comprehensive Perl
-Archive Network (CPAN). Visit <http://www.perl.com/CPAN/> to find a CPAN
-site near you. Or see L<http://search.cpan.org/dist/Test-CompanionClasses/>.
+Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
+site near you, or see
+L<http://search.cpan.org/dist/Test-CompanionClasses/>.
 
 The development version lives at
-L<http://github.com/hanekomu/test-companionclasses>. Instead of sending
-patches, please fork this project using the standard git and github
-infrastructure.
+L<http://github.com/hanekomu/Test-CompanionClasses/>.
+Instead of sending patches, please fork this project using the standard git
+and github infrastructure.
 
 =head1 AUTHOR
 
-Marcel GrE<uuml>nauer, C<< <marcel@cpan.org> >>
+  Marcel Gruenauer <marcel@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2007-2009 by Marcel GrE<uuml>nauer.
+This software is copyright (c) 2007 by Marcel Gruenauer.
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
