@@ -1,9 +1,10 @@
 package Test::CompanionClasses::Engine_TEST;
+# ABSTRACT: Test companion class for the test companion class engine
 use warnings;
 use strict;
 use Test::More;
 our $VERSION = '0.06';
-use base 'Test::CompanionClasses::Base';
+use parent 'Test::CompanionClasses::Base';
 use constant PLAN => 1;
 
 sub run {
@@ -13,17 +14,18 @@ sub run {
     can_ok($o, qw(new run_tests));
 }
 1;
+
+
 __END__
-
-
+=pod
 
 =head1 NAME
 
-Test::CompanionClasses::Engine_TEST - a test companion class
+Test::CompanionClasses::Engine_TEST - Test companion class for the test companion class engine
 
-=head1 SYNOPSIS
+=head1 VERSION
 
-    # None; this is part of C<Test::CompanionClasses> tests.
+version 1.100870
 
 =head1 DESCRIPTION
 
@@ -32,46 +34,44 @@ L<Test::CompanionClasses> itself.
 
 =head1 METHODS
 
-=over 4
-
-=item C<run>
+=head2 run
 
 Creates an object of its associated implementation class and checks that that
 object C<can()> run C<new()> and C<run_tests()> methods.
 
-=back
+=head1 INSTALLATION
+
+See perlmodinstall for information and options on installing Perl modules.
 
 =head1 BUGS AND LIMITATIONS
 
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org>.
-
-=head1 INSTALLATION
-
-See perlmodinstall for information and options on installing Perl modules.
+L<http://rt.cpan.org/Public/Dist/Display.html?Name=Test-CompanionClasses>.
 
 =head1 AVAILABILITY
 
 The latest version of this module is available from the Comprehensive Perl
-Archive Network (CPAN). Visit <http://www.perl.com/CPAN/> to find a CPAN
-site near you. Or see L<http://search.cpan.org/dist/Test-CompanionClasses/>.
+Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
+site near you, or see
+L<http://search.cpan.org/dist/Test-CompanionClasses/>.
 
 The development version lives at
-L<http://github.com/hanekomu/test-companionclasses>. Instead of sending
-patches, please fork this project using the standard git and github
-infrastructure.
+L<http://github.com/hanekomu/Test-CompanionClasses/>.
+Instead of sending patches, please fork this project using the standard git
+and github infrastructure.
 
 =head1 AUTHOR
 
-Marcel GrE<uuml>nauer, C<< <marcel@cpan.org> >>
+  Marcel Gruenauer <marcel@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2007-2009 by Marcel GrE<uuml>nauer.
+This software is copyright (c) 2007 by Marcel Gruenauer.
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
